@@ -296,16 +296,6 @@ class Network(Component):
         for i, conn in enumerate(self.connections):
             self.connections[i] = ":".join(part.strip() for part in conn.split(":"))
 
-        # sort connections (not truly necessary, but useful during manual inspecting)
-        def _conn_sort_key(conn):
-            try:
-                comp, idx, out = conn.split(":")
-                return "%03d" % int(out) + conn
-            except ValueError:
-                return conn
-
-        self.connections.sort(key=_conn_sort_key)
-
         # add components to components dict
         self.components = OrderedDict()
         for name in self._get_used_component_names():
@@ -557,7 +547,9 @@ class Network(Component):
             (2, int(delays_in_timesteps.max()) + 1, 1, self.num_mc, 1),
             device=self.device,
         )
-        self.buffermask[:, delays_in_timesteps[mc], :, range(self.num_mc), :] = 1.0
+        # effectively, MC nodes with 0 delay will have 1 timestep delay...
+        time_index = torch.max(delays_in_timesteps[mc] - 1, torch.tensor([0]))
+        self.buffermask[:, time_index, :, range(self.num_mc), :] = 1.0
 
         # finish initialization:
         self._env = env
